@@ -1,14 +1,18 @@
+import contextlib
 import io
 import os
 import sys
 import traceback
 from argparse import Namespace
+from enum import auto
 from pathlib import Path
 from textwrap import dedent
-from typing import Dict, Iterator, List, Optional, TextIO, TypeVar, Union
+from typing import Any, Dict, Iterator, List, Optional, TextIO, TypeVar, Union
 
+import click
 from cacheable_iter import iter_cache
 from pynmrstar import Entry, Loop, Saveframe
+from strenum import StrEnum
 
 from nef_pipelines.lib.constants import (
     EXIT_ERROR,
@@ -25,6 +29,7 @@ from nef_pipelines.lib.header_lib import (
 from nef_pipelines.lib.structures import LineInfo
 
 STDIN = Path("-")
+STDOUT = Path("-")
 
 
 def _get_loop_by_category_or_none(frame: Saveframe, category: str) -> Loop:
@@ -326,7 +331,18 @@ def script_name(file: str) -> Path:
     Returns:
         Path: path to the file
     """
-    return Path(file).name
+
+    current_context = click.get_current_context()
+
+    in_pytest = "pytest" in sys.modules
+    if in_pytest:
+        command = current_context.command_path.split()
+    else:
+        command = current_context.command_path.split()[1:]
+
+    command = f"{'/'.join(command)}.py"
+
+    return command
 
 
 def read_from_file_or_exit(file_name: Path, target: str) -> str:
@@ -377,7 +393,9 @@ def exit_error(msg, exception=None):
 
     print(file=sys.stderr)
 
-    print(f"ERROR: {msg[0]}", file=sys.stderr)
+    script = script_name(__file__)
+
+    print(f"ERROR [in {script}]: {msg[0]}", file=sys.stderr)
 
     for line in msg[1:]:
         print(f"       {line}", file=sys.stderr)
@@ -604,3 +622,70 @@ def end_with_ordinal(n):
 
 def get_display_file_name(file_name: Path) -> str:
     return "stdin" if file_name == STDIN else file_name
+
+
+class StdStream(StrEnum):
+    STDIN = auto()
+    STDOUT = auto()
+    STDERR = auto()
+
+
+STREAM_MODES = {StdStream.STDIN: "r", StdStream.STDOUT: "w", StdStream.STDERR: "w"}
+
+
+@contextlib.contextmanager
+def smart_open(filename=None, stream_type=StdStream.STDOUT):
+    f"""
+    context manager to open a file or use stdout depending on the filename, stdin is defined as '-'
+    by corollary a std stream won't be closed on exit only file system streams
+    :param filename: the filename to use '-' indicates a standar stream selected by stream_type
+    :param stream_type: how to treat the stream choices are {', '.join(StdStream.__members__)}
+
+    """
+
+    mode = STREAM_MODES[stream_type]
+    if filename and str(filename) != "-":
+        fh = open(filename, mode)
+    else:
+        fh = sys.stdout
+
+    try:
+        yield fh
+    finally:
+        if fh not in (sys.stdout, sys.stdin, sys.stderr):
+            fh.close()
+
+
+class DebugStdout:
+    """
+    class to intercept stdout and print debugging info of where strings ae printed from
+
+    usage:
+
+        from contextlib import redirect_stdout
+        with redirect_stdout(DebugStdout):
+            ... # your code here
+    """
+
+    def __init__(self, in_old_stdout):
+        self.old_stdout = in_old_stdout
+
+    def write(self, msg):
+        self.old_stdout.write(msg)
+        from inspect import currentframe, getframeinfo
+
+        frameinfo = getframeinfo(currentframe().f_back)
+
+        print(f" <-[{frameinfo.filename}, {frameinfo.lineno}]", file=sys.stderr)
+
+
+def flatten(in_list: Union[List[Any], List[Union[List[Any], Any]]]) -> List[Any]:
+    """
+    flatten a list of lists into a single list
+    :param in_list: a putative lists of lists
+    :return: a list of anything but lists
+    """
+    out = []
+    for sublist in in_list:
+        out.extend(sublist)
+    return out
